@@ -131,12 +131,12 @@ meteo_hourly <- function(rank, year, status = FALSE, coords = FALSE, station = N
   #station selection
   if (!is.null(station)) {
     if (is.character(station)) {
-      all_data <- all_data[all_data$id %in% station, ]
+      all_data <- all_data[all_data$`Nazwa stacji` %in% station, ]
       if (nrow(all_data) == 0){
         stop("Selected station(s) is not available in the database.", call. = FALSE)
       }
     } else if (is.numeric(station)){
-      all_data <- all_data[all_data$id%in% station, ]
+      all_data <- all_data[all_data$`Kod stacji`%in% station, ]
       if (nrow(all_data) == 0){
         stop("Selected station(s) is not available in the database.", call. = FALSE)
       }
